==> styletron-server-2.0.0.tgz: package/lib/test/index.js <==
var test = require('tape');
var fixtures = require('test-fixtures');

var cacheToCss = require('../cache-to-css');
var Styletron = require('../styletron-server');

var StyletronTest = (function (Styletron) {
  function StyletronTest() {
    var args = [], len = arguments.length;
    while ( len-- ) args[ len ] = arguments[ len ];

    Styletron.apply(this, args);
  }

  if ( Styletron ) StyletronTest.__proto__ = Styletron;
  StyletronTest.prototype = Object.create( Styletron && Styletron.prototype );
  StyletronTest.prototype.constructor = StyletronTest;
  StyletronTest.prototype.setCache = function setCache (cache) {
    this.cache = cache;
  };

  return StyletronTest;
}(Styletron));

test('test toCss', function (t) {
  t.equal(cacheToCss(fixtures.basic.cache), fixtures.basic.css);
  t.end();
});

test('test getCss method', function (t) {
  var instance = new StyletronTest();
  instance.setCache(fixtures.basic.cache);
  t.equal(instance.getCss(), fixtures.basic.css);
  t.end();
});

test('test getStylesheets method', function (t) {
  var instance = new StyletronTest();
  instance.setCache(fixtures.basic.cache);
  t.deepEqual(instance.getStylesheets(), [
    {
      css: '.c4:hover{display:none}.c0{color:red}.c1{color:green}'
    },
    {
      media: '(max-width: 800px)',
      css: '.c3:hover{color:green}.c2{color:green}'
    }
  ]);
  t.end();
});

test('test getStylesheetsHtml method', function (t) {
  var instance = new StyletronTest();
  instance.setCache(fixtures.basic.cache);
  t.equal(instance.getStylesheetsHtml(), '<style class="_styletron_hydrate_">.c4:hover{display:none}.c0{color:red}.c1{color:green}</style><style class="_styletron_hydrate_" media="(max-width: 800px)">.c3:hover{color:green}.c2{color:green}</style>');
  t.end();
});

==> styletron-server-2.0.1.tgz: package/lib/test/index.js <==
var test = require('tape');
var fixtures = require('test-fixtures');

var cacheToCss = require('../cache-to-css');
var Styletron = require('../styletron-server');

var StyletronTest = (function (Styletron) {
  function StyletronTest() {
    var args = [], len = arguments.length;
    while ( len-- ) args[ len ] = arguments[ len ];

    Styletron.apply(this, args);
  }

  if ( Styletron ) StyletronTest.__proto__ = Styletron;
  StyletronTest.prototype = Object.create( Styletron && Styletron.prototype );
  StyletronTest.prototype.constructor = StyletronTest;
  StyletronTest.prototype.setCache = function setCache (cache) {
    this.cache = cache;
  };

  return StyletronTest;
}(Styletron));

test('test toCss', function (t) {
  t.equal(cacheToCss(fixtures.basic.cache), fixtures.basic.css);
  t.end();
});

test('test getCss method', function (t) {
  var instance = new StyletronTest();
  instance.setCache(fixtures.basic.cache);
  t.equal(instance.getCss(), fixtures.basic.css);
  t.end();
});

test('test getStylesheets method', function (t) {
  var instance = new StyletronTest();
  instance.setCache(fixtures.basic.cache);
  t.deepEqual(instance.getStylesheets(), [
    {
      css: '.s4:hover{display:none}.s0{color:red}.s1{color:green}'
    },
    {
      media: '(max-width: 800px)',
      css: '.s3:hover{color:green}.s2{color:green}'
    }
  ]);
  t.end();
});

test('test getStylesheetsHtml method', function (t) {
  var instance = new StyletronTest();
  instance.setCache(fixtures.basic.cache);
  t.equal(instance.getStylesheetsHtml(), '<style class="_styletron_hydrate_">.s4:hover{display:none}.s0{color:red}.s1{color:green}</style><style class="_styletron_hydrate_" media="(max-width: 800px)">.s3:hover{color:green}.s2{color:green}</style>');
  t.end();
});
